Cell

Struct Cell 

pub struct Cell { /* private fields */ }
A pair of reference-counted nouns.

A cell can be:

  • created from an array of atoms, cells, nouns, or types that can easily be converted into atoms;
  • compared to other cells;
  • unpacked into an array of nouns;
  • pretty-printed;
  • converted into a noun.

Examples

To create a new cell, use one of the From<[T; N]> implementations:

let cell = Cell::from(["hello", "world"]);
assert_eq!(*cell.head(), Noun::from(Atom::from("hello")));
assert_eq!(*cell.tail(), Noun::from(Atom::from("world")));
let cell = Cell::from([0u8, 2u8, 4u8, 8u8]);
assert_eq!(*cell.head(), Noun::from(Atom::from(0u8)));
assert_eq!(*cell.tail(), Noun::from(Cell::from([2u8, 4u8, 8u8])));

Implementations

Source

impl Cell

pub fn head(&self) -> Rc<Noun>

Returns the head of this cell.

pub fn head_ref(&self) -> &Noun

Returns the head of this cell as a reference.

pub fn tail(&self) -> Rc<Noun>

Returns the tail of this cell.

pub fn tail_ref(&self) -> &Noun

Returns the tail of this cell as a reference.

pub fn hash(&self) -> u64

Computes the hash of this cell.

pub fn to_array<const N: usize>(&self) -> Option<[Rc<Noun>; N]>

Unpacks this cell into an array of length N, returning None if the cell is not of the form [a1 a2 ... aN].

Examples
let cell = Cell::from([0u8, 1u8, 2u8, 3u8, 4u8, 5u8]);

let nouns = cell.to_array::<6>().unwrap();
assert_eq!(*nouns[0], Noun::from(Atom::from(0u8)));
assert_eq!(*nouns[1], Noun::from(Atom::from(1u8)));
assert_eq!(*nouns[2], Noun::from(Atom::from(2u8)));
assert_eq!(*nouns[3], Noun::from(Atom::from(3u8)));
assert_eq!(*nouns[4], Noun::from(Atom::from(4u8)));
assert_eq!(*nouns[5], Noun::from(Atom::from(5u8)));
let cell = Cell::from([0u8, 1u8, 2u8, 3u8]);

assert_eq!(cell.to_array::<6>(), None);
pub fn to_vec(&self) -> Vec<Rc<Noun>>

Unpacks this cell into a vector.

If the length of the cell is known at compile-time, use to_array() instead.

Examples
let cell = Cell::from([0u8, 1u8, 2u8, 4u8, 8u8, 16u8, 32u8, 64u8, 128u8]);

let nouns = cell.to_vec();
assert_eq!(nouns.len(), 9);
assert_eq!(*nouns[0], Noun::from(Atom::from(0u8)));
assert_eq!(*nouns[1], Noun::from(Atom::from(1u8)));
assert_eq!(*nouns[2], Noun::from(Atom::from(2u8)));
assert_eq!(*nouns[3], Noun::from(Atom::from(4u8)));
assert_eq!(*nouns[4], Noun::from(Atom::from(8u8)));
assert_eq!(*nouns[5], Noun::from(Atom::from(16u8)));
assert_eq!(*nouns[6], Noun::from(Atom::from(32u8)));
assert_eq!(*nouns[7], Noun::from(Atom::from(64u8)));
assert_eq!(*nouns[8], Noun::from(Atom::from(128u8)));
pub fn into_parts(self) -> (Rc<Noun>, Rc<Noun>)

Converts this cell into its head and tail, consuming the cell.

pub fn as_noun(&self) -> Noun

pub fn into_noun(self) -> Noun

pub fn in_rc(&self) -> Rc<Noun>

pub fn slot(&self, axis: usize) -> Option<Rc<Noun>>

Returns the noun at the given axis, or None if the axis is invalid.

Examples
use axsys_noun::{atom::Atom, cell::Cell, Noun, cell};
let cell = Cell::from([0u8, 1u8, 2u8]);

assert_eq!(cell.slot(0), None);
assert_eq!(cell.slot(1), Some(cell.in_rc()));
assert_eq!(cell.slot(2), Some(cell.head()));
assert_eq!(cell.slot(3), Some(cell.tail()));
assert_eq!(cell.slot(6), Some(cell.tail().as_cell().unwrap().head()));
assert_eq!(cell.slot(7), Some(cell.tail().as_cell().unwrap().tail()));