pub enum Error {
AtomToUint,
AtomToStr,
ExpectedNull,
ImplType,
MissingValue,
UnexpectedAtom,
UnexpectedCell,
}Expand description
Errors that occur when converting from a noun.
Variants
AtomToUint
An atom could not be converted into an unsigned integer.
AtomToStr
An atom could not be converted into a string.
ExpectedNull
A null atom was expected.
ImplType
An error specific to the implementing type occurred.
MissingValue
No value exists at a particular axis of a cell.
UnexpectedAtom
Encountered an atom when a cell was expected.
UnexpectedCell
Encountered a cell when an atom was expected.